response_header

Function response_header 

pub fn response_header(
    header_name: impl Into<HeaderName<'static>>,
) -> impl LogFormatter
formatter-builder for a particular response header, formatted wrapped in quotes. "" if the header is not present

usage:

Logger::new().with_formatter((
    "location: ",
    response_header(trillium::KnownHeaderName::Location),
));
// or
Logger::new().with_formatter(("location: ", response_header("Location")));

note: this is not a formatter itself, but returns a formatter when called with a header name