pub fn secure(conn: &Conn, _: bool) -> &'static strExpand description
formatter that prints an emoji if the request is secure as determined
by Conn::is_secure
pub fn secure(conn: &Conn, _: bool) -> &'static strformatter that prints an emoji if the request is secure as determined
by Conn::is_secure