pub struct DevFormatter;Expand description
The default formatter: a simple colorized development-mode format
Renders as {version} {method} {url} {response_time} {status}, with the same components
as the formatters of those names. dev_formatter is the same format as a free function;
this type exists so the default can be named, as in Logger<DevFormatter>.